        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>1</strong> representante: <strong>4</strong> miembros: 29 <br>1,2,3,4,8,9,12,15,16,17,18,20,24,25,26,28,29,30,34,35,36,40,41,42,43,45,46,48,49';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260606 a 12</strong> UTC HH+018 (rango:012-024)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 22 <strong>control</strong><br>0,5,6,7,10,11,13,14,19,21,22,23,27,31,32,33,37,38,39,44,47,50';}
}
